@@ -68,10 +68,10 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
     backendModel->appendRow(item);
-    item = new QStandardItem(tr("SBB Legacy - Swiss"));
+/*    item = new QStandardItem(tr("SBB Legacy - Swiss")); //this backend is currently broken. 10. June 2011, CaCO3
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
-    backendModel->appendRow(item);
+    backendModel->appendRow(item); */
     item = new QStandardItem(tr("NSW - Australia"));
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
@@ -96,27 +96,27 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
 
     QString backendType = settings->value("backend", "parserMobileBahnDe").toString();
     //Read Settings
-    if (backendType == "parserMobileBahnDe")
+    if (backendType == "parserMobileBahnDe") //DB
     {
         backendSelector->setCurrentIndex(0);
-    } else if (backendType == "parserMvvDe")
+    } else if (backendType == "parserMvvDe") //MVV
     {
             backendSelector->setCurrentIndex(1);
-    } else if (backendType == "parserSbbCh")
+    }/* else if (backendType == "parserSbbCh")   //this backend is currently broken. 10. June 2011, CaCO3
     {
             backendSelector->setCurrentIndex(2);
-    } else if (backendType == "parser131500ComAu")
+    }*/ else if (backendType == "parser131500ComAu") //NSW
+    {
+            backendSelector->setCurrentIndex(2);
+    } else if (backendType == "parserXmlOebbAt") //OeBB
     {
             backendSelector->setCurrentIndex(3);
-    } else if (backendType == "parserXmlOebbAt")
+    } else if (backendType == "parserXmlSbbCh") //SBB
     {
-            backendSelector->setCurrentIndex(4);
-    } else if (backendType == "parserXmlSbbCh")
+        backendSelector->setCurrentIndex(4);
+    } else if (backendType == "parserXmlRejseplanenDk") //Denmark
     {
         backendSelector->setCurrentIndex(5);
-    } else if (backendType == "parserXmlRejseplanenDk")
-    {
-        backendSelector->setCurrentIndex(6);
     } else
     {
        //fallback is bahn.de
@@ -168,19 +168,19 @@ void configDialog::okButtonClicked()
     } else if (backendSelector->currentIndex() == 1)
     {
         settings->setValue("backend", "parserMvvDe");
-    } else if (backendSelector->currentIndex() == 2)
+    }/* else if (backendSelector->currentIndex() == 2)  //this backend is currently broken. 10. June 2011, CaCO3
     {
         settings->setValue("backend", "parserSbbCh");
-    } else if (backendSelector->currentIndex() == 3)
+    }*/ else if (backendSelector->currentIndex() == 2)
     {
         settings->setValue("backend", "parser131500ComAu");
-    } else if (backendSelector->currentIndex() == 4)
+    } else if (backendSelector->currentIndex() == 3)
     {
         settings->setValue("backend", "parserXmlOebbAt");
-    } else if (backendSelector->currentIndex() == 5)
+    } else if (backendSelector->currentIndex() == 4)
     {
         settings->setValue("backend", "parserXmlSbbCh");
-    } else if (backendSelector->currentIndex() == 6)
+    } else if (backendSelector->currentIndex() == 5)
     {
         settings->setValue("backend", "parserXmlRejseplanenDk");
     } else
