@@ -101,6 +101,17 @@ MainWindow::MainWindow(QWidget *parent)
 
     connect(searchButton, SIGNAL(clicked(bool)), this, SLOT(searchButtonClicked(bool)));
 
+    progressbar = new QDial();
+
+    progressbar->setEnabled(false);
+    progressbar->setWrapping(true);
+    progressbar->hide();
+
+    timer = new QTimer(this);
+    connect(timer, SIGNAL(timeout()), this, SLOT(updateProgress()));
+
+
+
     //Add all to Layout
     #ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -162,7 +173,8 @@ void MainWindow::orientationChanged()
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
     QGridLayout *layout = (QGridLayout*)this->centralWidget()->layout();
 
-    if (screenGeometry.width() > screenGeometry.height())
+
+    if (screenGeometry.width() > screenGeometry.height()) //landscape
     {
         layout->addWidget(dateSelector, 1, 0);
         layout->addWidget(timeSelector, 1, 1);
@@ -170,6 +182,11 @@ void MainWindow::orientationChanged()
         layout->addWidget(traintypesButton, 2, 1);
         layout->addWidget(searchButton, 3, 0, 1, 0);
 
+        layout->addWidget(progressbar, 0, 0);
+
+        progressbar->setFixedWidth(800);
+        progressbar->setFixedHeight(350);
+
         dateSelector->setFixedHeight(78);
         timeSelector->setFixedHeight(78);
         modeButton->setFixedHeight(78);
@@ -177,15 +194,21 @@ void MainWindow::orientationChanged()
         stationDeparture->setFixedHeight(78);
         stationArrival->setFixedHeight(78);
         stationSwap->setFixedHeight(160);
-        stationSwap->setFixedWidth(50);
+        stationSwap->setFixedWidth(100);
         searchButton->setFixedHeight(78);
-    } else {
+
+    } else { //portrait
         layout->addWidget(dateSelector, 1, 0, 1, 0);
         layout->addWidget(timeSelector, 2, 0, 1, 0);
         layout->addWidget(modeButton, 3, 0, 1, 0);
         layout->addWidget(traintypesButton, 4, 0, 1, 0);
         layout->addWidget(searchButton, 5, 0, 1, 0);
 
+        layout->addWidget(progressbar, 0, 0);
+
+        progressbar->setFixedWidth(440);
+        progressbar->setFixedHeight(650);
+
         dateSelector->setFixedHeight(98);
         timeSelector->setFixedHeight(98);
         modeButton->setFixedHeight(98);
@@ -193,15 +216,37 @@ void MainWindow::orientationChanged()
         stationDeparture->setFixedHeight(98);
         stationArrival->setFixedHeight(98);
         stationSwap->setFixedHeight(200);
-        stationSwap->setFixedWidth(50);
+        stationSwap->setFixedWidth(100);
         searchButton->setFixedHeight(98);
     }
 }
 
+
+
+
+void MainWindow::updateProgress(){
+    progress++;
+    qDebug() << progress;
+    if (!resultWindow){
+        progressbar->setValue((progress*5) % 100);
+    }
+    else{
+        progressbarResult->setValue((progress*5) % 100);
+    }
+
+    if(progress > 250){ // 20ms * 50 * 5 = 5 sec
+        backendParser->httpRequestTimeout();
+    }
+}
+
+
+
 void MainWindow::initBackend(bool resetStations)
 {
     QString backendType = settings->value("backend", "parserMobileBahnDe").toString();
 
+
+
     //Init Parser Backend
     if (backendType == "parserMobileBahnDe")
     {
@@ -211,11 +256,11 @@ void MainWindow::initBackend(bool resetStations)
     {
         backendParser = new parserMvvDe();
         setWindowTitle("Fahrplan (MVV)");
-    } else if (backendType == "parserSbbCh")
+    }/* else if (backendType == "parserSbbCh")  //this backend is currently broken. 10. June 2011, CaCO3
     {
         backendParser = new parserSbbCh();
         setWindowTitle("Fahrplan (SBB-Legacy)");
-    } else if (backendType == "parser131500ComAu")
+    }*/ else if (backendType == "parser131500ComAu")
     {
         backendParser = new parser131500ComAu();
         setWindowTitle("Fahrplan (NSW)");
@@ -334,6 +379,13 @@ void MainWindow::alarmButtonClicked()
     calDlg->open();
 }
 
+
+void MainWindow::alarmDefaultButtonClicked()
+{
+    calendarDialog *calDlg = new calendarDialog(lastSearchDetails, this);
+    calDlg->addToDefaultCalendar();
+}
+
 void MainWindow::donateButtonClicked()
 {
     QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=DW3LGJ6VEKFVS"));
@@ -345,7 +397,7 @@ void MainWindow::donateButtonClicked()
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
-    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>DB</b>, <b>MVV</b>, <b>SBB</b>, <b>BB</b>, <b>Rejseplanen.dk</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
+    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>and CaCO3 (george@ruinelli.ch)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>DB</b>, <b>MVV</b>, <b>SBB</b>, <b>BB</b>, <b>Rejseplanen.dk</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
     QMessageBox::about(this,
                        tr("About Fahrplan"),
                        tr(aboutMsg.toAscii()));
@@ -363,12 +415,23 @@ void MainWindow::resultItemClicked()
     QPushButton *button = (QPushButton *)sender();
     ResultItemUserData *data = (ResultItemUserData*)button->userData(0);
 
+    qDebug() << "resultItemClicked";
+
     if (detailsLoading != true)
     {
         detailsLoading = true;
 
+
+        progress=0;
+        progressbarResult->show();
+        timer->start(20); //start timer with 20ms interval
+
         lastSearchDetails = backendParser->getJourneyDetailsData(data->item.detailsUrl);
 
+        progressbarResult->hide();
+//        scrollAreaResult->show();
+        timer->stop();
+
         detailsLoading = false;
 
         showDetailsWindow();
@@ -386,7 +449,12 @@ void MainWindow::showDetailsWindow()
         detailsWindow->hide();
     }
 
-    if (lastSearchDetails.items.count() == 0)
+
+    if(progress>250){
+        QMaemo5InformationBox::information(this, "<br>No response from server.<br>", QMaemo5InformationBox::DefaultTimeout);
+        return;
+    }
+    else  if (lastSearchDetails.items.count() == 0)
     {
         QMaemo5InformationBox::information(this, tr("<br>Error opening the details.<br>") + lastSearchResult.errorMsg, QMaemo5InformationBox::DefaultTimeout);
         return;
@@ -403,7 +471,12 @@ void MainWindow::showDetailsWindow()
             this, SLOT(windowDestroyed(QObject*)));
 
     //Alarm Menu Button
-    QAction *alarmAct = new QAction(tr("Add to calendar"), this);
+    QAction *alarmActDefault = new QAction(tr("Add to default calendar"), this);
+    connect(alarmActDefault, SIGNAL(triggered()), this, SLOT(alarmDefaultButtonClicked()));
+    detailsWindow->menuBar()->addAction(alarmActDefault);
+
+
+    QAction *alarmAct = new QAction(tr("Add to a calendar"), this);
     connect(alarmAct, SIGNAL(triggered()), this, SLOT(alarmButtonClicked()));
     detailsWindow->menuBar()->addAction(alarmAct);
 
@@ -518,7 +591,12 @@ void MainWindow::showResultWindow()
         resultWindow->hide();
     }
 
-    if (lastSearchResult.items.count() == 0)
+    if(progress>250){
+        QMaemo5InformationBox::information(this, "<br>No response from server.<br>", QMaemo5InformationBox::DefaultTimeout);
+        searchButton->setEnabled(true);
+        return;
+    }
+    else if (lastSearchResult.items.count() == 0)
     {
         QMaemo5InformationBox::information(this, tr("<br>No results found.<br>") + lastSearchResult.errorMsg + "<br>", QMaemo5InformationBox::DefaultTimeout);
         searchButton->setEnabled(true);
@@ -553,6 +631,13 @@ void MainWindow::showResultWindow()
     QWidget *mainWidget = new QWidget;
     resultWindow->setCentralWidget(mainWidget);
 
+    progressbarResult = new QDial();
+
+    progressbarResult->setEnabled(false);
+    progressbarResult->setWrapping(true);
+    progressbarResult->hide();
+
+
     //Header
     QLabel *headerLabel = new QLabel("<center><b>" + lastSearchResult.fromStation +
                                      "</b> " +
@@ -581,7 +666,7 @@ void MainWindow::showResultWindow()
     QWidget *itemsWidget = new QWidget;
     QVBoxLayout *itemLayout = new QVBoxLayout;
     itemLayout->setMargin(10);
-    QScrollArea *scrollArea = new QScrollArea;
+    QScrollArea *scrollAreaResult = new QScrollArea;
 
     ResultItem item;
     foreach(item, lastSearchResult.items)
@@ -597,10 +682,23 @@ void MainWindow::showResultWindow()
 
         if (item.fromTime != "")
         {
+            //correct result displaying
+//            qDebug() << item.fromTime << item.toTime;
+            QStringList list = item.toTime.split(" ");
+//            qDebug() << list.size();
+            if(list.size()>1){ //arrival is not on same day
+                item.toTime = list[1];
+            }
+//            qDebug() << item.fromTime << item.toTime;
+
             buttonText.append("<b>" + item.fromTime + " - " +
                               item.toTime + "</b> ");
         }
 
+        //correct result displaying
+        item.trainType.replace(" ", "");
+        item.trainType.replace(",", ", ");
+
         buttonText.append(item.trainType + " (" +
                           changes + ") - " +
                           item.duration);
@@ -660,16 +758,22 @@ void MainWindow::showResultWindow()
 
     itemsWidget->setLayout(itemLayout);
 
-    scrollArea->setWidget(itemsWidget);
+    scrollAreaResult->setWidget(itemsWidget);
 
     //Main Layout
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setMargin(1);
     layout->addWidget(headerLabel);
-    layout->addWidget(scrollArea);
+    layout->addWidget(scrollAreaResult);
+    layout->addWidget(progressbarResult);
+
+
+    progressbarResult->setFixedHeight(100);
 
     mainWidget->setLayout(layout);
 
+
+
     resultWindow->show();
     //qDebug() << "Window" << resultWindow;
 }
@@ -698,6 +802,9 @@ void MainWindow::laterButtonClicked()
     showResultWindow();
 }
 
+
+
+
 void MainWindow::searchButtonClicked(bool checked)
 {
     Q_UNUSED(checked);
@@ -740,7 +847,16 @@ void MainWindow::searchButtonClicked(bool checked)
             }
 
             searchButton->setEnabled(false);
+
+            progress=0;
+            progressbar->show();
+            timer->start(20); //start timer with 20ms interval
+
             lastSearchResult = backendParser->getJourneyData(stationDeparture->description(), stationArrival->description(), "", dateSel->currentDate(), timeSel->currentTime(), mode->mode, trainrestrictions);
+
+            progressbar->hide();
+            timer->stop();
+
             showResultWindow();
         } else
         {
@@ -749,6 +865,11 @@ void MainWindow::searchButtonClicked(bool checked)
     }
 }
 
+
+
+
+
+
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     //qDebug() <<"close event";
