@@ -203,7 +203,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
     QString xhtml = filebuffer->buffer();
 
     //We use Regex to get each element details page
-    QRegExp regexp = QRegExp("<div class=\"rline haupt\"  >(.*)</div>");
+    QRegExp regexp = QRegExp("<div class=\"rline haupt\".*>(.*)</div>");
     regexp.setMinimal(true);
 
     int idx = 0;
